package com.mortals.xhx.module.dept.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.dept.model.vo.DeptVo;
import com.mortals.xhx.module.dept.service.DeptService;
import com.mortals.xhx.module.site.model.SiteEntity;
import com.mortals.xhx.module.site.service.SiteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 部门
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("dept")
public class DeptController extends BaseCRUDJsonBodyMappingController<DeptService, DeptEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private SiteService siteService;

    public DeptController() {
        super.setFormClass(DeptForm.class);
        super.setModuleDesc("部门");
    }

    @Override
    protected void doListBefore(DeptEntity query, Map<String, Object> model, Context context) throws AppException {
        query.setOrderColList(new ArrayList<OrderCol>() {
            {
                add(new OrderCol("a.sort", OrderCol.ASCENDING));
                add(new OrderCol("a.createTime", OrderCol.ASCENDING));
            }
        });
        super.doListBefore(query, model, context);
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "isAutotable", paramService.getParamBySecondOrganize("Dept", "isAutotable"));
        this.addDict(model, "isOrder", paramService.getParamBySecondOrganize("Dept", "isOrder"));
        this.addDict(model, "isBkb", paramService.getParamBySecondOrganize("Dept", "isBkb"));
        this.addDict(model, "isWorkGuide", paramService.getParamBySecondOrganize("Dept", "isWorkGuide"));
        this.addDict(model, "usValid", paramService.getParamBySecondOrganize("Dept", "usValid"));
        this.addDict(model, "isSecphone", paramService.getParamBySecondOrganize("Dept", "isSecphone"));
        this.addDict(model, "isEnglish", paramService.getParamBySecondOrganize("Dept", "isEnglish"));
        super.init(model, context);
    }


    /**
     * 根据站点同步部门
     */
    @PostMapping(value = "syncDeptBySiteId")
    public String syncDeptBySiteId(Long siteId) {
        JSONObject jsonObject = new JSONObject();
        Map<String, Object> model = new HashMap<>();
        SiteEntity siteEntity = siteService.get(siteId, getContext());
        try {
            Rest<String> rest = this.service.syncDeptBySiteId(siteEntity, getContext());
            jsonObject.put(KEY_RESULT_MSG, rest.getMsg());
            jsonObject.put(KEY_RESULT_DATA, model);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            this.recordSysLog(this.request, rest.getMsg());
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }


    /**
     * 根据部门查询业务
     */
    @PostMapping(value = "getBusinessByDept")
    @UnAuth
    public String getBusinessByDept(@RequestBody DeptQuery deptQuery) {
        JSONObject jsonObject = new JSONObject();
        String busiDesc = "根据部门查询业务" + this.getModuleDesc();
        try {
            if (ObjectUtils.isEmpty(deptQuery.getIdList())) {
                throw new AppException("参数部门ids不能为空！");
            }
            Rest<Map<String, List<DeptVo>>> rest = this.service.getBusinessByDept(deptQuery, getContext());
            recordSysLog(request, busiDesc + " 【成功】");
            jsonObject.put(KEY_RESULT_DATA, rest.getData());
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            jsonObject.put(KEY_RESULT_MSG, busiDesc + "成功！");
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }


    /**
     * 根据部门查询业务
     */
    @PostMapping(value = "getDeptListByBusiness")
    @UnAuth
    public String getDeptListByBusiness(@RequestBody DeptQuery deptQuery) {
        JSONObject jsonObject = new JSONObject();
        String busiDesc = "根据业务查询部门列表" + this.getModuleDesc();
        try {
            if (ObjectUtils.isEmpty(deptQuery.getSiteBusinessIdList())) {
                throw new AppException("业务id不能为空！");
            }
            Rest<Map<String, List<DeptVo>>> rest = this.service.getDeptListByBusiness(deptQuery, getContext());
            recordSysLog(request, busiDesc + " 【成功】");
            jsonObject.put(KEY_RESULT_DATA, rest.getData());
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            jsonObject.put(KEY_RESULT_MSG, busiDesc + "成功！");
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }




}