package com.mortals.xhx.module.matter.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.framework.web.BasePhpCRUDJsonMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.matter.model.MatterDatumEntity;
import com.mortals.xhx.module.matter.model.MatterDatumFileEntity;
import com.mortals.xhx.module.matter.model.MatterDatumFileQuery;
import com.mortals.xhx.module.matter.service.MatterDatumFileService;
import com.mortals.xhx.module.matter.service.MatterDatumService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 事项申请材料
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("matter/datum")
public class MatterDatumController extends BaseCRUDJsonBodyMappingController<MatterDatumService, MatterDatumEntity, Long> {

    @Autowired
    private ParamService paramService;
    @Autowired
    private MatterDatumFileService matterDatumFileService;

    public MatterDatumController() {
        super.setFormClass(MatterDatumForm.class);
        super.setModuleDesc("事项申请材料");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "isMust", paramService.getParamBySecondOrganize("MatterDatum", "isMust"));
        this.addDict(model, "materialType", paramService.getParamBySecondOrganize("MatterDatum", "materialType"));
        this.addDict(model, "materialProperty", paramService.getParamBySecondOrganize("MatterDatum", "materialProperty"));
        this.addDict(model, "electronicgs", paramService.getParamBySecondOrganize("MatterDatum", "electronicgs"));
        this.addDict(model, "materialSource", paramService.getParamBySecondOrganize("MatterDatum", "materialSource"));
        this.addDict(model, "paperNum", paramService.getParamBySecondOrganize("MatterDatum", "paperNum"));
        this.addDict(model, "jianmMs", paramService.getParamBySecondOrganize("MatterDatum", "jianmMs"));
        this.addDict(model, "isjianm", paramService.getParamBySecondOrganize("MatterDatum", "isjianm"));
        this.addDict(model, "isLack", paramService.getParamBySecondOrganize("MatterDatum", "isLack"));
        this.addDict(model, "source", paramService.getParamBySecondOrganize("MatterDatum", "source"));
        super.init(model, context);
    }


    @Override
    protected int viewAfter(Long id, Map<String, Object> model, MatterDatumEntity entity, Context context) throws AppException {
        List<MatterDatumFileEntity> matterDatumFileEntities = matterDatumFileService.find(new MatterDatumFileQuery().datumId(entity.getId()));
        entity.setDatumFileList(matterDatumFileEntities);
        return super.viewAfter(id, model, entity, context);
    }

    /**
     * 添加事项到站点
     */
    @PostMapping(value = "addToLibrary")
    public String addToLibrary(@RequestBody Map<String, Object> map) {
        JSONObject jsonObject = new JSONObject();
        Map<String, Object> model = new HashMap<String, Object>();
        String datumIds = (String) map.get("datumIds");
        Long siteId = DataUtil.converStr2Long(map.get("siteId").toString(), 0L);

        try {
            Rest<String> rest = this.service.addToLibrary(datumIds, siteId, getContext());
            jsonObject.put(KEY_RESULT_MSG, rest.getMsg());
            jsonObject.put(KEY_RESULT_DATA, model);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            this.recordSysLog(this.request, rest.getMsg());
        } catch (Exception e) {
            log.error("获取异常", e);
            jsonObject.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            jsonObject.put(KEY_RESULT_MSG, super.convertException(e));
        }
        return jsonObject.toJSONString();
    }
}